package shop.itbug.xiaomi_badger

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.util.Log
import androidx.annotation.NonNull

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import me.leolin.shortcutbadger.ShortcutBadger
import shop.itbug.xiaomi_badger.service.NotifService
import shop.itbug.xiaomi_badger.util.BadgerUtils
import shop.itbug.xiaomi_badger.util.OppoBadgeUtil
import shop.itbug.xiaomi_badger.util.SystemUtil

class XiaomiBadgerPlugin : FlutterPlugin, MethodCallHandler,ActivityAware {


    companion object {
        const val tag = "XiaomiBadgerPlugin"
    }

    private lateinit var channel: MethodChannel
    private lateinit var context: Context
    private lateinit var activity: Activity

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "xiaomi_badger")
        channel.setMethodCallHandler(this)
        context = flutterPluginBinding.applicationContext
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "push" -> {
                val params = call.arguments as Map<*, *>
                val badgeCount = params["badgeCount"] as Int
                val title = params["title"] as String
                val content = params["content"] as String
                val intent = Intent(context, NotifService::class.java)
                Log.d(tag,"badgeCount:$badgeCount, title: $title, content: $content")
                intent.putExtra("badgeCount", badgeCount)
                intent.putExtra("title", title)
                intent.putExtra("content", content)
                context.startService(intent)
            }

            /// vivo 设置小角标
            "vivo-push" -> {
                val params = call.arguments as Map<*, *>
                val badgeCount = params["badgeCount"] as Int
                BadgerUtils.setVivoBadge(context,badgeCount)
            }
            "oppo-push" -> {
                val params = call.arguments as Map<*, *>
                val badgeCount = params["badgeCount"] as Int
                val title = params["title"] as String
                val content = params["content"] as String
                BadgerUtils.setNotificationBadge(
                    context = activity,
                    count = badgeCount,
                    content = content,
                    title = title
                )
                OppoBadgeUtil.executeBadge(activity,badgeCount)
            }
            "brand"->{
                result.success(SystemUtil.getDeviceBrand()?:"null")
            }
            "remove" -> {
                ShortcutBadger.removeCount(context)
            }
            else -> {
                result.notImplemented()
            }
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    }

    override fun onDetachedFromActivity() {
    }
}
