package shop.itbug.xiaomi_badger.util

import android.R
import android.annotation.SuppressLint
import android.app.*
import android.content.*
import android.graphics.BitmapFactory
import android.net.Uri
import android.os.Build
import android.os.Bundle
import android.util.Log
import androidx.core.app.NotificationCompat


object BadgerUtils {
    var notificationId = 100

    //xiaomi oppo 通用
    fun setNotificationBadge(context: Context, count: Int, content: String,title: String) {
        val notificationManager =
            context.getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            // 8.0之后添加角标需要NotificationChannel
            val channel = NotificationChannel(
                "badge", "小角标通知",
                NotificationManager.IMPORTANCE_DEFAULT
            )
            channel.setShowBadge(true)
            channel.enableLights(false)
            channel.enableVibration(false)
            channel.setSound(null, null)
            notificationManager.createNotificationChannel(channel)
        }
        if (context !is Activity) {
            Log.d("BadgerUtils", "xiaomi or oppo not set On MainActivity、it's wrong")
            return
        }
        val intent = Intent(context, context.javaClass)
        val pendingIntent = PendingIntent.getActivity(context, 0, intent, 0)
        val notification: Notification = NotificationCompat.Builder(context, "badge")
            .setContentTitle(title)
            .setContentText(content)
            .setSmallIcon(R.drawable.ic_dialog_alert)
            .setAutoCancel(true)
            .setContentIntent(pendingIntent)
            .setChannelId("badge")
            .setNumber(count)
            .setBadgeIconType(NotificationCompat.BADGE_ICON_SMALL).build()
        // 小米
//        try {
//            val field = notification.javaClass.getDeclaredField("extraNotification")
//            val extraNotification: Any = field.get(notification)
//            val method = extraNotification.javaClass.getDeclaredMethod(
//                "setMessageCount",
//                Int::class.java
//            )
//            method.invoke(extraNotification, count)
//        } catch (e: Exception) {
//            e.printStackTrace()
//        }
        notificationManager.notify(notificationId++, notification)
    }

    //华为
    fun setHuaweiBadge(context: Context, count: Int): Boolean {
        return try {
            val launchClassName =
                context.packageManager.getLaunchIntentForPackage(context.packageName)!!
                    .component!!.className
            val bundle = Bundle()
            bundle.putString("package", context.packageName)
            bundle.putString("class", launchClassName)
            bundle.putInt("badgenumber", count)
            context.contentResolver.call(
                Uri.parse(
                    "content://com.huawei.android.launcher" +
                            ".settings/badge/"
                ), "change_badge", null, bundle
            )
            true
        } catch (e: Exception) {
            e.printStackTrace()
            false
        }
    }

    //vivo
    @SuppressLint("WrongConstant")
    fun setVivoBadge(context: Context, count: Int) {
        try {
            val launchClassName =
                context.packageManager.getLaunchIntentForPackage(context.packageName)!!
                    .component!!.className
            val intent = Intent()
            intent.action = "launcher.action.CHANGE_APPLICATION_NOTIFICATION_NUM"
            intent.putExtra("packageName", context.packageName)
            intent.putExtra("className", launchClassName)
            intent.putExtra("notificationNum", count)
            intent.addFlags(0x01000000)
            context.sendBroadcast(intent)
            Log.d("BADGE -- 梁典典","package-name:${context.packageName}\n" +
                    "className:${launchClassName}\n" +
                    "notificationNum:$count")
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

    //三星
    fun setSamsungBadge(context: Context, count: Int) {
        try {
            val launchClassName =
                context.packageManager.getLaunchIntentForPackage(context.packageName)!!
                    .component!!.className
            val intent = Intent("android.intent.action.BADGE_COUNT_UPDATE")
            intent.putExtra("badge_count", count)
            intent.putExtra("badge_count_package_name", context.packageName)
            intent.putExtra("badge_count_class_name", launchClassName)
            context.sendBroadcast(intent)
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

    //    联想ZUK（支持）
    fun setZukBadge(context: Context, count: Int) {
        try {
            val extra = Bundle()
            val ids = ArrayList<String>()
            // 以列表形式传递快捷方式id，可以添加多个快捷方式id
//        ids.add("custom_id_1");
//        ids.add("custom_id_2");
            extra.putStringArrayList("app_shortcut_custom_id", ids)
            extra.putInt("app_badge_count", count)
            val contentUri = Uri.parse("content://com.android.badge/badge")
            val bundle = context.contentResolver.call(
                contentUri, "setAppBadgeCount", null,
                extra
            )
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

    //HTC
    fun setHTCBadge(context: Context, count: Int) {
        try {
            val launcherComponentName =
                context.packageManager.getLaunchIntentForPackage(context.packageName)!!
                    .component
            val intent1 = Intent("com.htc.launcher.action.SET_NOTIFICATION")
            if (launcherComponentName != null) {
                intent1.putExtra(
                    "com.htc.launcher.extra.COMPONENT", launcherComponentName
                        .flattenToShortString()
                )
            }
            intent1.putExtra("com.htc.launcher.extra.COUNT", count)
            context.sendBroadcast(intent1)
            val intent2 = Intent("com.htc.launcher.action.UPDATE_SHORTCUT")
            intent2.putExtra("packagename", launcherComponentName!!.packageName)
            intent2.putExtra("count", count)
            context.sendBroadcast(intent2)
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

    //索尼
    fun setSonyBadge(context: Context, count: Int) {
        try {
            //官方给出方法
            val launchClassName =
                context.packageManager.getLaunchIntentForPackage(context.packageName)!!
                    .component!!.className
            val contentValues = ContentValues()
            contentValues.put("badge_count", count)
            contentValues.put("package_name", context.packageName)
            contentValues.put("activity_name", launchClassName)
            val asyncQueryHandler = SonyAsyncQueryHandler(
                context
                    .contentResolver
            )
            asyncQueryHandler.startInsert(
                0, null, Uri.parse(
                    "content://com.sonymobile.home" +
                            ".resourceprovider/badge"
                ), contentValues
            )
        } catch (e: Exception) {
            try {
                //网上大部分使用方法
                val launchClassName =
                    context.packageManager.getLaunchIntentForPackage(context.packageName)!!
                        .component!!.className
                val intent = Intent("com.sonyericsson.home.action.UPDATE_BADGE")
                intent.putExtra("com.sonyericsson.home.intent.extra.badge.SHOW_MESSAGE", count > 0)
                intent.putExtra(
                    "com.sonyericsson.home.intent.extra.badge.ACTIVITY_NAME",
                    launchClassName
                )
                intent.putExtra(
                    "com.sonyericsson.home.intent.extra.badge.MESSAGE",
                    count.toString()
                )
                intent.putExtra(
                    "com.sonyericsson.home.intent.extra.badge.PACKAGE_NAME", context
                        .packageName
                )
                context.sendBroadcast(intent)
            } catch (e1: Exception) {
                e1.printStackTrace()
            }
        }
    }

    internal class SonyAsyncQueryHandler(cr: ContentResolver?) :
        AsyncQueryHandler(cr)
}